@@ -69,6 +69,7 @@ from inputremapper.gui.utils import (
     CTX_APPLY,
     CTX_WARNING,
     gtk_iteration,
+    debounce,
 )
 
 
@@ -201,6 +202,9 @@ class UserInterface:
         self.get("vertical-wrapper").set_opacity(0)
         self.window = window
 
+        source_view = self.get("code_editor")
+        source_view.get_buffer().connect("changed", self.check_on_typing)
+
         # if any of the next steps take a bit to complete, have the window
         # already visible (without content) to make it look more responsive.
         gtk_iteration()
@@ -465,6 +469,12 @@ class UserInterface:
             status_bar.push(context_id, message)
             status_bar.set_tooltip_text(tooltip)
 
+    @debounce(500)
+    def check_on_typing(self, *_):
+        """To save latest input from code editor and call syntax check."""
+        self.editor.gather_changes_and_save()
+        self.check_macro_syntax()
+
     def check_macro_syntax(self):
         """Check if the programmed macros are allright."""
         self.show_status(CTX_MAPPING, None)
