@@ -36,7 +36,6 @@ w(1000).m(Shift_L, r(2, k(a))).w(10).k(b): <1s> A A <10ms> b
 
 
 import asyncio
-import copy
 import re
 
 from evdev.ecodes import ecodes, EV_KEY, EV_REL, REL_X, REL_Y, REL_WHEEL, REL_HWHEEL
@@ -265,17 +264,17 @@ class Macro:
         self.keystroke_sleep_ms = self.context.preset.get("macros.keystroke_sleep_ms")
 
         self.running = True
-        for task in self.tasks:
-            try:
+
+        try:
+            for task in self.tasks:
                 coroutine = task(handler)
                 if asyncio.iscoroutine(coroutine):
                     await coroutine
-            except Exception as e:
-                logger.error(f'Macro "%s" failed: %s', self.code, e)
-                break
-
-        # done
-        self.running = False
+        except Exception as e:
+            raise
+        finally:
+            # done
+            self.running = False
 
     def press_trigger(self):
         """The user pressed the trigger key down."""
@@ -329,6 +328,32 @@ class Macro:
 
         self.tasks.append(task)
 
+    def add_key_down(self, symbol):
+        """Press the symbol."""
+        _type_check_symbol(symbol)
+
+        async def task(handler):
+            resolved_symbol = _resolve(symbol, [str])
+            code = _type_check_symbol(resolved_symbol)
+
+            resolved_code = _resolve(code, [int])
+            handler(EV_KEY, resolved_code, 1)
+
+        self.tasks.append(task)
+
+    def add_key_up(self, symbol):
+        """Release the symbol."""
+        _type_check_symbol(symbol)
+
+        async def task(handler):
+            resolved_symbol = _resolve(symbol, [str])
+            code = _type_check_symbol(resolved_symbol)
+
+            resolved_code = _resolve(code, [int])
+            handler(EV_KEY, resolved_code, 0)
+
+        self.tasks.append(task)
+
     def add_hold(self, macro=None):
         """Loops the execution until key release."""
         _type_check(macro, [Macro, str, None], "hold", 1)
@@ -386,7 +411,6 @@ class Macro:
             handler(EV_KEY, code, 1)
             await self._keycode_pause()
             await macro.run(handler)
-            await self._keycode_pause()
             handler(EV_KEY, code, 0)
             await self._keycode_pause()
 
@@ -466,11 +490,14 @@ class Macro:
             "right": (REL_X, 1),
         }[direction.lower()]
 
+        # how long to pause in ms between the injection of mouse events
+        injection_throttle = 10
+
         async def task(handler):
             resolved_speed = value * _resolve(speed, [int])
             while self.is_holding():
                 handler(EV_REL, code, resolved_speed)
-                await self._keycode_pause()
+                await asyncio.sleep(injection_throttle / 1000)
 
         self.tasks.append(task)
 
