@@ -19,20 +19,36 @@
 # along with input-remapper.  If not, see <https://www.gnu.org/licenses/>.
 
 
-"""Sets up inputremapper for the tests and runs them."""
+"""Sets up inputremapper for the tests and runs them.
+
+This module needs to be imported first in test files.
+"""
+
+import argparse
 import os
 import sys
 import tempfile
 
-# the working directory should be the project root
-assert not os.getcwd().endswith("tests")
-assert not os.getcwd().endswith("unit")
-assert not os.getcwd().endswith("integration")
+
+def get_project_root():
+    """Find the projects root, i.e. the uppermost directory of the repo."""
+    # when tests are started in pycharm via the green arrow, the working directory
+    # is not the project root. Go up until it is found.
+    root = os.getcwd()
+    for _ in range(10):
+        if "setup.py" in os.listdir(root):
+            return root
+
+        root = os.path.dirname(root)
+
+    raise Exception("Could not find project root")
+
 
 # make sure the "tests" module visible
-sys.path.append(os.getcwd())
+sys.path.append(get_project_root())
 if __name__ == "__main__":
-    # import this file to itself to make sure is not run twice and all global variables end up in sys.modules
+    # import this file to itself to make sure is not run twice and all global
+    # variables end up in sys.modules
     # https://stackoverflow.com/questions/13181559/importing-modules-main-vs-import-as-module
     import tests.test
 
@@ -51,11 +67,6 @@ from pickle import UnpicklingError
 from unittest.mock import patch
 
 import evdev
-import gi
-
-gi.require_version("Gtk", "3.0")
-gi.require_version("GLib", "2.0")
-gi.require_version("GtkSource", "4")
 
 from tests.xmodmap import xmodmap
 
@@ -110,8 +121,8 @@ EVENT_READ_TIMEOUT = 0.01
 START_READING_DELAY = 0.05
 
 # for joysticks
-MIN_ABS = -(2 ** 15)
-MAX_ABS = 2 ** 15
+MIN_ABS = -(2**15)
+MAX_ABS = 2**15
 
 # When it gets garbage collected it cleans up the temporary directory so it needs to
 # stay reachable while the tests are ran.
@@ -288,12 +299,12 @@ def new_event(type, code, value, timestamp=None, offset=0):
 
     sec = int(timestamp)
     usec = timestamp % 1 * 1000000
-    event = evdev.InputEvent(sec, usec, type, code, value)
+    event = InputEvent(sec, usec, type, code, value)
     return event
 
 
 def patch_paths():
-    from inputremapper import paths
+    from inputremapper.configs import paths
 
     paths.CONFIG_PATH = tmp
 
@@ -418,6 +429,9 @@ class InputDevice:
 
         return result
 
+    def input_props(self):
+        return []
+
 
 uinputs = {}
 
@@ -527,12 +541,12 @@ from inputremapper.logger import update_verbosity
 update_verbosity(True)
 
 from inputremapper.injection.injector import Injector
-from inputremapper.config import config
+from inputremapper.configs.global_config import global_config
 from inputremapper.gui.reader import reader
 from inputremapper.groups import groups
-from inputremapper.system_mapping import system_mapping
-from inputremapper.gui.custom_mapping import custom_mapping
-from inputremapper.paths import get_config_path
+from inputremapper.configs.system_mapping import system_mapping
+from inputremapper.gui.active_preset import active_preset
+from inputremapper.configs.paths import get_config_path
 from inputremapper.injection.macros.macro import macro_variables
 from inputremapper.injection.consumers.keycode_mapper import active_macros, unreleased
 from inputremapper.injection.global_uinputs import global_uinputs
@@ -558,7 +572,7 @@ def send_event_to_reader(event):
 def quick_cleanup(log=True):
     """Reset the applications state."""
     if log:
-        print("quick cleanup")
+        print("Quick cleanup...")
 
     for device in list(pending_events.keys()):
         try:
@@ -600,15 +614,15 @@ def quick_cleanup(log=True):
     if os.path.exists(tmp):
         shutil.rmtree(tmp)
 
-    config.path = os.path.join(get_config_path(), "config.json")
-    config.clear_config()
-    config._save_config()
+    global_config.path = os.path.join(get_config_path(), "config.json")
+    global_config.clear_config()
+    global_config._save_config()
 
     system_mapping.populate()
 
-    custom_mapping.empty()
-    custom_mapping.clear_config()
-    custom_mapping.set_has_unsaved_changes(False)
+    active_preset.empty()
+    active_preset.clear_config()
+    active_preset.set_has_unsaved_changes(False)
 
     clear_write_history()
 
@@ -641,13 +655,18 @@ def quick_cleanup(log=True):
         uinput.write_count = 0
         uinput.write_history = []
 
+    global_uinputs.is_service = True
+
+    if log:
+        print("Quick cleanup done")
+
 
 def cleanup():
     """Reset the applications state.
 
     Using this is slower, usually quick_cleanup() is sufficient.
     """
-    print("cleanup")
+    print("Cleanup...")
 
     os.system("pkill -f input-remapper-service")
     os.system("pkill -f input-remapper-control")
@@ -656,7 +675,9 @@ def cleanup():
     quick_cleanup(log=False)
     groups.refresh()
     with patch.object(sys, "argv", ["input-remapper-service"]):
-        global_uinputs.prepare()
+        global_uinputs.prepare_all()
+
+    print("Cleanup done")
 
 
 def spy(obj, name):
@@ -668,7 +689,15 @@ cleanup()
 
 
 def main():
-    modules = sys.argv[1:]
+    # https://docs.python.org/3/library/argparse.html
+    parser = argparse.ArgumentParser(description=__doc__)
+    # repeated argument 0 or more times with modules
+    parser.add_argument("modules", type=str, nargs="*")
+    # start-dir value if not using modules, allows eg python tests/test.py --start-dir unit
+    parser.add_argument("--start-dir", type=str, default=".")
+    parsed_args = parser.parse_args()  # takes from sys.argv by default
+    modules = parsed_args.modules
+
     # discoverer is really convenient, but it can't find a specific test
     # in all of the available tests like unittest.main() does...,
     # so provide both options.
@@ -679,7 +708,9 @@ def main():
         testsuite = unittest.defaultTestLoader.loadTestsFromNames(modules)
     else:
         # run all tests by default
-        testsuite = unittest.defaultTestLoader.discover(".", pattern="test_*.py")
+        testsuite = unittest.defaultTestLoader.discover(
+            parsed_args.start_dir, pattern="test_*.py"
+        )
 
     # add a newline to each "qux (foo.bar)..." output before each test,
     # because the first log will be on the same line otherwise
