@@ -19,54 +19,6 @@
 # along with input-remapper.  If not, see <https://www.gnu.org/licenses/>.
 
 
-import unittest
-from unittest import mock
-import time
-import copy
-
-import evdev
-from evdev.ecodes import (
-    EV_REL,
-    EV_KEY,
-    EV_ABS,
-    ABS_HAT0X,
-    BTN_LEFT,
-    KEY_A,
-    REL_X,
-    REL_Y,
-    REL_WHEEL,
-    REL_HWHEEL,
-    BTN_A,
-    ABS_X,
-    ABS_Y,
-    ABS_Z,
-    ABS_RZ,
-    ABS_VOLUME,
-    KEY_B,
-    KEY_C,
-)
-
-from inputremapper.injection.consumers.joystick_to_mouse import JoystickToMouse
-from inputremapper.injection.injector import (
-    Injector,
-    is_in_capabilities,
-    STARTING,
-    RUNNING,
-    STOPPED,
-    NO_GRAB,
-    UNKNOWN,
-    get_udev_name,
-)
-from inputremapper.injection.numlock import is_numlock_on, set_numlock, ensure_numlock
-from inputremapper.system_mapping import system_mapping, DISABLE_CODE, DISABLE_NAME
-from inputremapper.gui.custom_mapping import custom_mapping
-from inputremapper.mapping import Mapping
-from inputremapper.config import config, NONE, MOUSE, WHEEL, BUTTONS
-from inputremapper.key import Key
-from inputremapper.injection.macros.parse import parse
-from inputremapper.injection.context import Context
-from inputremapper.groups import groups, classify, GAMEPAD
-
 from tests.test import (
     new_event,
     push_events,
@@ -82,6 +34,55 @@ from tests.test import (
     MIN_ABS,
 )
 
+import unittest
+from unittest import mock
+import time
+
+import evdev
+from evdev.ecodes import (
+    EV_REL,
+    EV_KEY,
+    EV_ABS,
+    ABS_HAT0X,
+    KEY_A,
+    REL_X,
+    REL_Y,
+    REL_WHEEL,
+    REL_HWHEEL,
+    BTN_A,
+    ABS_X,
+    ABS_Y,
+    ABS_Z,
+    ABS_RZ,
+    ABS_VOLUME,
+    KEY_C,
+)
+
+from inputremapper.injection.consumers.joystick_to_mouse import JoystickToMouse
+from inputremapper.injection.injector import (
+    Injector,
+    is_in_capabilities,
+    STARTING,
+    RUNNING,
+    STOPPED,
+    NO_GRAB,
+    UNKNOWN,
+    get_udev_name,
+)
+from inputremapper.injection.numlock import is_numlock_on
+from inputremapper.configs.system_mapping import (
+    system_mapping,
+    DISABLE_CODE,
+    DISABLE_NAME,
+)
+from inputremapper.gui.active_preset import active_preset
+from inputremapper.configs.preset import Preset
+from inputremapper.configs.global_config import global_config, NONE, MOUSE, WHEEL
+from inputremapper.event_combination import EventCombination
+from inputremapper.injection.macros.parse import parse
+from inputremapper.injection.context import Context
+from inputremapper.groups import groups, classify, GAMEPAD
+
 
 def wait_for_uinput_write():
     start = time.time()
@@ -131,12 +132,12 @@ class TestInjector(unittest.IsolatedAsyncioTestCase):
         # path is from the fixtures
         path = "/dev/input/event10"
 
-        custom_mapping.change(Key(EV_KEY, 10, 1), "keyboard", "a")
+        active_preset.change(EventCombination([EV_KEY, 10, 1]), "keyboard", "a")
 
-        self.injector = Injector(groups.find(key="Foo Device 2"), custom_mapping)
+        self.injector = Injector(groups.find(key="Foo Device 2"), active_preset)
         # this test needs to pass around all other constraints of
         # _grab_device
-        self.injector.context = Context(custom_mapping)
+        self.injector.context = Context(active_preset)
         device = self.injector._grab_device(path)
         gamepad = classify(device) == GAMEPAD
         self.assertFalse(gamepad)
@@ -146,11 +147,11 @@ class TestInjector(unittest.IsolatedAsyncioTestCase):
 
     def test_fail_grab(self):
         self.make_it_fail = 999
-        custom_mapping.change(Key(EV_KEY, 10, 1), "keyboard", "a")
+        active_preset.change(EventCombination([EV_KEY, 10, 1]), "keyboard", "a")
 
-        self.injector = Injector(groups.find(key="Foo Device 2"), custom_mapping)
+        self.injector = Injector(groups.find(key="Foo Device 2"), active_preset)
         path = "/dev/input/event10"
-        self.injector.context = Context(custom_mapping)
+        self.injector.context = Context(active_preset)
         device = self.injector._grab_device(path)
         self.assertIsNone(device)
         self.assertGreaterEqual(self.failed, 1)
@@ -165,9 +166,9 @@ class TestInjector(unittest.IsolatedAsyncioTestCase):
         self.assertEqual(self.injector.get_state(), NO_GRAB)
 
     def test_grab_device_1(self):
-        custom_mapping.change(Key(EV_ABS, ABS_HAT0X, 1), "keyboard", "a")
-        self.injector = Injector(groups.find(name="gamepad"), custom_mapping)
-        self.injector.context = Context(custom_mapping)
+        active_preset.change(EventCombination([EV_ABS, ABS_HAT0X, 1]), "keyboard", "a")
+        self.injector = Injector(groups.find(name="gamepad"), active_preset)
+        self.injector.context = Context(active_preset)
 
         _grab_device = self.injector._grab_device
         # doesn't have the required capability
@@ -179,17 +180,17 @@ class TestInjector(unittest.IsolatedAsyncioTestCase):
 
     def test_gamepad_purpose_none(self):
         # forward abs joystick events
-        custom_mapping.set("gamepad.joystick.left_purpose", NONE)
-        config.set("gamepad.joystick.right_purpose", NONE)
+        active_preset.set("gamepad.joystick.left_purpose", NONE)
+        global_config.set("gamepad.joystick.right_purpose", NONE)
 
-        self.injector = Injector(groups.find(name="gamepad"), custom_mapping)
-        self.injector.context = Context(custom_mapping)
+        self.injector = Injector(groups.find(name="gamepad"), active_preset)
+        self.injector.context = Context(active_preset)
 
         path = "/dev/input/event30"
         device = self.injector._grab_device(path)
         self.assertIsNone(device)  # no capability is used, so it won't grab
 
-        custom_mapping.change(Key(EV_KEY, BTN_A, 1), "keyboard", "a")
+        active_preset.change(EventCombination([EV_KEY, BTN_A, 1]), "keyboard", "a")
         device = self.injector._grab_device(path)
         self.assertIsNotNone(device)
         gamepad = classify(device) == GAMEPAD
@@ -197,42 +198,42 @@ class TestInjector(unittest.IsolatedAsyncioTestCase):
 
     def test_gamepad_purpose_none_2(self):
         # forward abs joystick events for the left joystick only
-        custom_mapping.set("gamepad.joystick.left_purpose", NONE)
-        config.set("gamepad.joystick.right_purpose", MOUSE)
+        active_preset.set("gamepad.joystick.left_purpose", NONE)
+        global_config.set("gamepad.joystick.right_purpose", MOUSE)
 
-        self.injector = Injector(groups.find(name="gamepad"), custom_mapping)
-        self.injector.context = Context(custom_mapping)
+        self.injector = Injector(groups.find(name="gamepad"), active_preset)
+        self.injector.context = Context(active_preset)
 
         path = "/dev/input/event30"
         device = self.injector._grab_device(path)
         # the right joystick maps as mouse, so it is grabbed
-        # even with an empty mapping
+        # even with an empty preset
         self.assertIsNotNone(device)
         gamepad = classify(device) == GAMEPAD
         self.assertTrue(gamepad)
 
-        custom_mapping.change(Key(EV_KEY, BTN_A, 1), "keyboard", "a")
+        active_preset.change(EventCombination([EV_KEY, BTN_A, 1]), "keyboard", "a")
         device = self.injector._grab_device(path)
         gamepad = classify(device) == GAMEPAD
         self.assertIsNotNone(device)
         self.assertTrue(gamepad)
 
     def test_skip_unused_device(self):
-        # skips a device because its capabilities are not used in the mapping
-        custom_mapping.change(Key(EV_KEY, 10, 1), "keyboard", "a")
-        self.injector = Injector(groups.find(key="Foo Device 2"), custom_mapping)
-        self.injector.context = Context(custom_mapping)
+        # skips a device because its capabilities are not used in the preset
+        active_preset.change(EventCombination([EV_KEY, 10, 1]), "keyboard", "a")
+        self.injector = Injector(groups.find(key="Foo Device 2"), active_preset)
+        self.injector.context = Context(active_preset)
         path = "/dev/input/event11"
         device = self.injector._grab_device(path)
         self.assertIsNone(device)
         self.assertEqual(self.failed, 0)
 
     def test_skip_unknown_device(self):
-        custom_mapping.change(Key(EV_KEY, 10, 1), "keyboard", "a")
+        active_preset.change(EventCombination([EV_KEY, 10, 1]), "keyboard", "a")
 
-        # skips a device because its capabilities are not used in the mapping
-        self.injector = Injector(groups.find(key="Foo Device 2"), custom_mapping)
-        self.injector.context = Context(custom_mapping)
+        # skips a device because its capabilities are not used in the preset
+        self.injector = Injector(groups.find(key="Foo Device 2"), active_preset)
+        self.injector.context = Context(active_preset)
         path = "/dev/input/event11"
         device = self.injector._grab_device(path)
 
@@ -240,36 +241,12 @@ class TestInjector(unittest.IsolatedAsyncioTestCase):
         self.assertEqual(self.failed, 0)
         self.assertIsNone(device)
 
-    def test_numlock(self):
-        before = is_numlock_on()
-
-        set_numlock(not before)  # should change
-        self.assertEqual(not before, is_numlock_on())
-
-        @ensure_numlock
-        def wrapped_1():
-            set_numlock(not is_numlock_on())
-
-        @ensure_numlock
-        def wrapped_2():
-            pass
-
-        # should not change
-        wrapped_1()
-        self.assertEqual(not before, is_numlock_on())
-        wrapped_2()
-        self.assertEqual(not before, is_numlock_on())
-
-        # toggle one more time to restore the previous configuration
-        set_numlock(before)
-        self.assertEqual(before, is_numlock_on())
-
     def test_gamepad_to_mouse(self):
         # maps gamepad joystick events to mouse events
-        config.set("gamepad.joystick.non_linearity", 1)
+        global_config.set("gamepad.joystick.non_linearity", 1)
         pointer_speed = 80
-        config.set("gamepad.joystick.pointer_speed", pointer_speed)
-        config.set("gamepad.joystick.left_purpose", MOUSE)
+        global_config.set("gamepad.joystick.pointer_speed", pointer_speed)
+        global_config.set("gamepad.joystick.left_purpose", MOUSE)
 
         # they need to sum up before something is written
         divisor = 10
@@ -285,7 +262,7 @@ class TestInjector(unittest.IsolatedAsyncioTestCase):
             ],
         )
 
-        self.injector = Injector(groups.find(name="gamepad"), custom_mapping)
+        self.injector = Injector(groups.find(name="gamepad"), active_preset)
         self.injector.start()
 
         # wait for the injector to start sending, at most 1s
@@ -332,12 +309,12 @@ class TestInjector(unittest.IsolatedAsyncioTestCase):
             * 2,
         )
 
-        custom_mapping.set("gamepad.joystick.left_purpose", NONE)
-        custom_mapping.set("gamepad.joystick.right_purpose", NONE)
+        active_preset.set("gamepad.joystick.left_purpose", NONE)
+        active_preset.set("gamepad.joystick.right_purpose", NONE)
         # BTN_A -> 77
-        custom_mapping.change(Key((1, BTN_A, 1)), "keyboard", "b")
+        active_preset.change(EventCombination([1, BTN_A, 1]), "keyboard", "b")
         system_mapping._set("b", 77)
-        self.injector = Injector(groups.find(name="gamepad"), custom_mapping)
+        self.injector = Injector(groups.find(name="gamepad"), active_preset)
         self.injector.start()
 
         # wait for the injector to start sending, at most 1s
@@ -368,9 +345,9 @@ class TestInjector(unittest.IsolatedAsyncioTestCase):
 
         # ABS_Z -> 77
         # ABS_RZ is not mapped
-        custom_mapping.change(Key((EV_ABS, ABS_Z, 1)), "keyboard", "b")
+        active_preset.change(EventCombination((EV_ABS, ABS_Z, 1)), "keyboard", "b")
         system_mapping._set("b", 77)
-        self.injector = Injector(groups.find(name="gamepad"), custom_mapping)
+        self.injector = Injector(groups.find(name="gamepad"), active_preset)
         self.injector.start()
 
         # wait for the injector to start sending, at most 1s
@@ -385,9 +362,9 @@ class TestInjector(unittest.IsolatedAsyncioTestCase):
 
     @mock.patch("evdev.InputDevice.ungrab")
     def test_gamepad_to_mouse_joystick_to_mouse(self, ungrab_patch):
-        custom_mapping.set("gamepad.joystick.left_purpose", MOUSE)
-        custom_mapping.set("gamepad.joystick.right_purpose", NONE)
-        self.injector = Injector(groups.find(name="gamepad"), custom_mapping)
+        active_preset.set("gamepad.joystick.left_purpose", MOUSE)
+        active_preset.set("gamepad.joystick.right_purpose", NONE)
+        self.injector = Injector(groups.find(name="gamepad"), active_preset)
         # the stop message will be available in the pipe right away,
         # so run won't block and just stop. all the stuff
         # will be initialized though, so that stuff can be tested
@@ -406,15 +383,15 @@ class TestInjector(unittest.IsolatedAsyncioTestCase):
         self.assertEqual(joystick_to_mouse._abs_range[0], MIN_ABS)
         self.assertEqual(joystick_to_mouse._abs_range[1], MAX_ABS)
         self.assertEqual(
-            self.injector.context.mapping.get("gamepad.joystick.left_purpose"), MOUSE
+            self.injector.context.preset.get("gamepad.joystick.left_purpose"), MOUSE
         )
 
         self.assertEqual(ungrab_patch.call_count, 1)
 
     def test_device1_not_a_gamepad(self):
-        custom_mapping.set("gamepad.joystick.left_purpose", MOUSE)
-        custom_mapping.set("gamepad.joystick.right_purpose", WHEEL)
-        self.injector = Injector(groups.find(key="Foo Device 2"), custom_mapping)
+        active_preset.set("gamepad.joystick.left_purpose", MOUSE)
+        active_preset.set("gamepad.joystick.right_purpose", WHEEL)
+        self.injector = Injector(groups.find(key="Foo Device 2"), active_preset)
         self.injector.stop_injecting()
         self.injector.run()
 
@@ -422,7 +399,7 @@ class TestInjector(unittest.IsolatedAsyncioTestCase):
         self.assertEqual(len(self.injector._consumer_controls), 0)
 
     def test_get_udev_name(self):
-        self.injector = Injector(groups.find(key="Foo Device 2"), custom_mapping)
+        self.injector = Injector(groups.find(key="Foo Device 2"), active_preset)
         suffix = "mapped"
         prefix = "input-remapper"
         expected = f'{prefix} {"a" * (80 - len(suffix) - len(prefix) - 2)} {suffix}'
@@ -437,14 +414,18 @@ class TestInjector(unittest.IsolatedAsyncioTestCase):
 
     @mock.patch("evdev.InputDevice.ungrab")
     def test_capabilities_and_uinput_presence(self, ungrab_patch):
-        custom_mapping.change(Key(EV_KEY, KEY_A, 1), "keyboard", "c")
-        custom_mapping.change(Key(EV_REL, REL_HWHEEL, 1), "keyboard", "k(b)")
-        self.injector = Injector(groups.find(key="Foo Device 2"), custom_mapping)
+        active_preset.change(EventCombination([EV_KEY, KEY_A, 1]), "keyboard", "c")
+        active_preset.change(
+            EventCombination([EV_REL, REL_HWHEEL, 1]), "keyboard", "k(b)"
+        )
+        self.injector = Injector(groups.find(key="Foo Device 2"), active_preset)
         self.injector.stop_injecting()
         self.injector.run()
 
         self.assertEqual(
-            self.injector.context.mapping.get_mapping(Key(EV_KEY, KEY_A, 1)),
+            self.injector.context.preset.get_mapping(
+                EventCombination([EV_KEY, KEY_A, 1])
+            ),
             ("c", "keyboard"),
         )
         self.assertEqual(
@@ -452,7 +433,9 @@ class TestInjector(unittest.IsolatedAsyncioTestCase):
             (KEY_C, "keyboard"),
         )
         self.assertEqual(
-            self.injector.context.mapping.get_mapping(Key(EV_REL, REL_HWHEEL, 1)),
+            self.injector.context.preset.get_mapping(
+                EventCombination([EV_REL, REL_HWHEEL, 1])
+            ),
             ("k(b)", "keyboard"),
         )
         self.assertEqual(
@@ -488,14 +471,14 @@ class TestInjector(unittest.IsolatedAsyncioTestCase):
 
         numlock_before = is_numlock_on()
 
-        combination = Key((EV_KEY, 8, 1), (EV_KEY, 9, 1))
-        custom_mapping.change(combination, "keyboard", "k(KEY_Q).k(w)")
-        custom_mapping.change(Key(EV_ABS, ABS_HAT0X, -1), "keyboard", "a")
+        combination = EventCombination((EV_KEY, 8, 1), (EV_KEY, 9, 1))
+        active_preset.change(combination, "keyboard", "k(KEY_Q).k(w)")
+        active_preset.change(EventCombination([EV_ABS, ABS_HAT0X, -1]), "keyboard", "a")
         # one mapping that is unknown in the system_mapping on purpose
         input_b = 10
-        custom_mapping.change(Key(EV_KEY, input_b, 1), "keyboard", "b")
+        active_preset.change(EventCombination([EV_KEY, input_b, 1]), "keyboard", "b")
 
-        # stuff the custom_mapping outputs (except for the unknown b)
+        # stuff the active_preset outputs (except for the unknown b)
         system_mapping.clear()
         code_a = 100
         code_q = 101
@@ -522,7 +505,7 @@ class TestInjector(unittest.IsolatedAsyncioTestCase):
             ],
         )
 
-        self.injector = Injector(groups.find(name="Bar Device"), custom_mapping)
+        self.injector = Injector(groups.find(name="Bar Device"), active_preset)
         self.assertEqual(self.injector.get_state(), UNKNOWN)
         self.injector.start()
         self.assertEqual(self.injector.get_state(), STARTING)
@@ -602,8 +585,8 @@ class TestInjector(unittest.IsolatedAsyncioTestCase):
         d_down = (EV_TYPE, CODE_2, 1)
         d_up = (EV_TYPE, CODE_2, 0)
 
-        custom_mapping.change(Key(*w_down[:2], -1), "keyboard", "w")
-        custom_mapping.change(Key(*d_down[:2], 1), "keyboard", "k(d)")
+        active_preset.change(EventCombination([*w_down[:2], -1]), "keyboard", "w")
+        active_preset.change(EventCombination([*d_down[:2], 1]), "keyboard", "k(d)")
 
         system_mapping.clear()
         code_w = 71
@@ -629,7 +612,7 @@ class TestInjector(unittest.IsolatedAsyncioTestCase):
                 ],
             )
 
-            self.injector = Injector(groups.find(name="gamepad"), custom_mapping)
+            self.injector = Injector(groups.find(name="gamepad"), active_preset)
 
             # the injector will otherwise skip the device because
             # the capabilities don't contain EV_TYPE
@@ -668,8 +651,8 @@ class TestInjector(unittest.IsolatedAsyncioTestCase):
         # should be forwarded and present in the capabilities
         hw_left = (EV_REL, REL_HWHEEL, -1)
 
-        custom_mapping.change(Key(*hw_right), "keyboard", "k(b)")
-        custom_mapping.change(Key(*w_up), "keyboard", "c")
+        active_preset.change(EventCombination(hw_right), "keyboard", "k(b)")
+        active_preset.change(EventCombination(w_up), "keyboard", "c")
 
         system_mapping.clear()
         code_b = 91
@@ -687,7 +670,7 @@ class TestInjector(unittest.IsolatedAsyncioTestCase):
         )
 
         group = groups.find(key=group_key)
-        self.injector = Injector(group, custom_mapping)
+        self.injector = Injector(group, active_preset)
 
         device = InputDevice("/dev/input/event11")
         # make sure this test uses a device that has the needed capabilities
@@ -738,12 +721,12 @@ class TestInjector(unittest.IsolatedAsyncioTestCase):
         self.assertEqual(len(events), 3)
 
     def test_store_permutations_for_macros(self):
-        mapping = Mapping()
+        mapping = Preset()
         ev_1 = (EV_KEY, 41, 1)
         ev_2 = (EV_KEY, 42, 1)
         ev_3 = (EV_KEY, 43, 1)
         # a combination
-        mapping.change(Key(ev_1, ev_2, ev_3), "keyboard", "k(a)")
+        mapping.change(EventCombination(ev_1, ev_2, ev_3), "keyboard", "k(a)")
         self.injector = Injector(groups.find(key="Foo Device 2"), mapping)
 
         history = []
@@ -771,15 +754,17 @@ class TestInjector(unittest.IsolatedAsyncioTestCase):
             self.assertEqual(macros[(ev_2, ev_1, ev_3)][0].code, "k(a)")
 
     def test_key_to_code(self):
-        mapping = Mapping()
+        mapping = Preset()
         ev_1 = (EV_KEY, 41, 1)
         ev_2 = (EV_KEY, 42, 1)
         ev_3 = (EV_KEY, 43, 1)
         ev_4 = (EV_KEY, 44, 1)
-        mapping.change(Key(ev_1), "keyboard", "a")
+        mapping.change(EventCombination(ev_1), "keyboard", "a")
         # a combination
-        mapping.change(Key(ev_2, ev_3, ev_4), "keyboard", "b")
-        self.assertEqual(mapping.get_mapping(Key(ev_2, ev_3, ev_4)), ("b", "keyboard"))
+        mapping.change(EventCombination(ev_2, ev_3, ev_4), "keyboard", "b")
+        self.assertEqual(
+            mapping.get_mapping(EventCombination(ev_2, ev_3, ev_4)), ("b", "keyboard")
+        )
 
         system_mapping.clear()
         system_mapping._set("a", 51)
@@ -798,18 +783,18 @@ class TestInjector(unittest.IsolatedAsyncioTestCase):
         self.assertEqual(len(injector.context.key_to_code), 3)
 
     def test_is_in_capabilities(self):
-        key = Key(1, 2, 1)
+        key = EventCombination([1, 2, 1])
         capabilities = {1: [9, 2, 5]}
         self.assertTrue(is_in_capabilities(key, capabilities))
 
-        key = Key((1, 2, 1), (1, 3, 1))
+        key = EventCombination((1, 2, 1), (1, 3, 1))
         capabilities = {1: [9, 2, 5]}
         # only one of the codes of the combination is required.
-        # The goal is to make combinations across those sub-devices possible,
+        # The goal is to make combinations= across those sub-devices possible,
         # that make up one hardware device
         self.assertTrue(is_in_capabilities(key, capabilities))
 
-        key = Key((1, 2, 1), (1, 5, 1))
+        key = EventCombination((1, 2, 1), (1, 5, 1))
         capabilities = {1: [9, 2, 5]}
         self.assertTrue(is_in_capabilities(key, capabilities))
 
@@ -856,18 +841,18 @@ class TestModifyCapabilities(unittest.TestCase):
                 assert absinfo is True
                 return self._capabilities
 
-        mapping = Mapping()
-        mapping.change(Key(EV_KEY, 80, 1), "keyboard", "a")
-        mapping.change(Key(EV_KEY, 81, 1), "keyboard", DISABLE_NAME)
+        mapping = Preset()
+        mapping.change(EventCombination([EV_KEY, 80, 1]), "keyboard", "a")
+        mapping.change(EventCombination([EV_KEY, 81, 1]), "keyboard", DISABLE_NAME)
 
         macro_code = "r(2, m(sHiFt_l, r(2, k(1).k(2))))"
         macro = parse(macro_code, mapping)
 
-        mapping.change(Key(EV_KEY, 60, 111), "keyboard", macro_code)
+        mapping.change(EventCombination([EV_KEY, 60, 111]), "keyboard", macro_code)
 
         # going to be ignored, because EV_REL cannot be mapped, that's
         # mouse movements.
-        mapping.change(Key(EV_REL, 1234, 3), "keyboard", "b")
+        mapping.change(EventCombination([EV_REL, 1234, 3]), "keyboard", "b")
 
         self.a = system_mapping.get("a")
         self.shift_l = system_mapping.get("ShIfT_L")
@@ -892,7 +877,9 @@ class TestModifyCapabilities(unittest.TestCase):
         quick_cleanup()
 
     def test_copy_capabilities(self):
-        self.mapping.change(Key(EV_KEY, 60, 1), "keyboard", self.macro.code)
+        self.mapping.change(
+            EventCombination([EV_KEY, 60, 1]), "keyboard", self.macro.code
+        )
 
         # I don't know what ABS_VOLUME is, for now I would like to just always
         # remove it until somebody complains, since its presence broke stuff
