@@ -26,10 +26,20 @@ import shutil
 import unittest
 import logging
 
-from inputremapper.logger import logger, add_filehandler, update_verbosity, log_info
+from inputremapper.logger import logger, update_verbosity, log_info, ColorfulFormatter
 from inputremapper.configs.paths import remove
 
 
+def add_filehandler(log_path):
+    """Start logging to a file."""
+    log_path = os.path.expanduser(log_path)
+    os.makedirs(os.path.dirname(log_path), exist_ok=True)
+    file_handler = logging.FileHandler(log_path)
+    file_handler.setFormatter(ColorfulFormatter())
+    logger.addHandler(file_handler)
+    logger.info('Starting logging to "%s"', log_path)
+
+
 class TestLogger(unittest.TestCase):
     def tearDown(self):
         update_verbosity(debug=True)
@@ -77,22 +87,6 @@ class TestLogger(unittest.TestCase):
         add_filehandler(new_path)
         self.assertTrue(os.path.exists(new_path))
 
-    def test_clears_log(self):
-        path = os.path.join(tmp, "logger-test")
-        os.makedirs(os.path.dirname(path), exist_ok=True)
-        os.mknod(path)
-
-        with open(path, "w") as f:
-            f.write("aaaa\n" * 2000 + "end")
-
-        add_filehandler(os.path.join(tmp, "logger-test"))
-        with open(path, "r") as f:
-            # it only keeps the newest information
-            content = f.readlines()
-            self.assertLess(len(content), 1100)
-            # whatever the logging module decides to log into that file
-            self.assertNotIn("aaaa", content[-1])
-
     def test_debug(self):
         path = os.path.join(tmp, "logger-test")
         add_filehandler(path)
