@@ -32,8 +32,6 @@ from evdev.ecodes import (
     EV_REL,
     EV_KEY,
     REL_Y,
-    REL_X,
-    REL_WHEEL,
     REL_HWHEEL,
     KEY_A,
     KEY_B,
@@ -90,7 +88,7 @@ class MacroTestBase(unittest.IsolatedAsyncioTestCase):
 
     def handler(self, ev_type, code, value):
         """Where macros should write codes to."""
-        print(f"\033[90mmacro wrote{(ev_type, code, value)}\033[0m")
+        logger.info(f"macro wrote{(ev_type, code, value)}")
         self.result.append((ev_type, code, value))
 
 
@@ -266,16 +264,13 @@ class TestMacros(MacroTestBase):
         self.assertTrue(is_this_a_macro("a + b + c"))
 
     def test_handle_plus_syntax(self):
-        self.assertEqual(handle_plus_syntax("a + b"), "modify(a,modify(b,hold()))")
-        self.assertEqual(
-            handle_plus_syntax("a + b + c"), "modify(a,modify(b,modify(c,hold())))"
-        )
-        self.assertEqual(
-            handle_plus_syntax(" a+b+c "), "modify(a,modify(b,modify(c,hold())))"
-        )
+        self.assertEqual(handle_plus_syntax("a + b"), "hold_keys(a,b)")
+        self.assertEqual(handle_plus_syntax("a + b + c"), "hold_keys(a,b,c)")
+        self.assertEqual(handle_plus_syntax(" a+b+c "), "hold_keys(a,b,c)")
 
-        # invalid
-        strings = ["+", "a+", "+b", "key(a + b)"]
+        # invalid. The last one with `key` should not have been a parameter
+        # of this function to begin with.
+        strings = ["+", "a+", "+b", "a\n+\n+\nb", "key(a + b)"]
         for string in strings:
             with self.assertRaises(ValueError):
                 logger.info(f'testing "%s"', string)
@@ -287,7 +282,7 @@ class TestMacros(MacroTestBase):
 
     def test_parse_plus_syntax(self):
         macro = parse("a + b")
-        self.assertEqual(macro.code, "modify(a,modify(b,hold()))")
+        self.assertEqual(macro.code, "hold_keys(a,b)")
 
         # this is not erroneously recognized as "plus" syntax
         macro = parse("key(a) # a + b")
@@ -369,6 +364,9 @@ class TestMacros(MacroTestBase):
         # have a meaning in the macro syntax.
         self.assertEqual(_parse_recurse("foo", self.context), "foo")
 
+        self.assertEqual(_parse_recurse("", self.context), None)
+        self.assertEqual(_parse_recurse("None", self.context), None)
+
         self.assertEqual(_parse_recurse("5", self.context), 5)
         self.assertEqual(_parse_recurse("5.2", self.context), 5.2)
         self.assertIsInstance(_parse_recurse("$foo", self.context), Variable)
@@ -498,6 +496,8 @@ class TestMacros(MacroTestBase):
         self.assertIsNone(error)
         error = parse("ifeq(a, 2, , k(a))", self.context, True)
         self.assertIsNone(error)
+        error = parse("ifeq(a, 2, None, k(a))", self.context, True)
+        self.assertIsNone(error)
         error = parse("ifeq(a, 2, 1,)", self.context, True)
         self.assertIsNotNone(error)
         error = parse("ifeq(a, 2, , 2)", self.context, True)
@@ -546,6 +546,24 @@ class TestMacros(MacroTestBase):
             ],
         )
 
+    async def test_key_down_up(self):
+        code_a = system_mapping.get("a")
+        code_b = system_mapping.get("b")
+        macro = parse(
+            "set(foo, b).key_down($foo).key_up($foo).key_up(a).key_down(a)",
+            self.context,
+        )
+        await macro.run(self.handler)
+        self.assertListEqual(
+            self.result,
+            [
+                (EV_KEY, code_b, 1),
+                (EV_KEY, code_b, 0),
+                (EV_KEY, code_a, 0),
+                (EV_KEY, code_a, 1),
+            ],
+        )
+
     async def test_modify(self):
         code_a = system_mapping.get("a")
         code_b = system_mapping.get("b")
@@ -970,7 +988,8 @@ class TestMacros(MacroTestBase):
         try:
             # should timeout, because the previous event doesn't match the filter
             await asyncio.wait_for(
-                macro._wait_for_event(lambda e, a: e.value == 3), 0.1
+                macro._wait_for_event(lambda e, a: e.value == 3),
+                0.1,
             )
             raise AssertionError("Expected asyncio.TimeoutError")
         except asyncio.TimeoutError:
@@ -991,10 +1010,12 @@ class TestMacros(MacroTestBase):
         # the first parameter for `repeat` requires an integer, not "foo",
         # which makes `repeat` throw
         macro = parse('set(a, "foo").repeat($a, key(KEY_A)).key(KEY_B)', self.context)
-        await macro.run(self.handler)
 
-        # .run() it will not throw because repeat() breaks, and it will properly set
-        # it to stopped
+        try:
+            await macro.run(self.handler)
+        except TypeError as e:
+            self.assertIn("foo", str(e))
+
         self.assertFalse(macro.running)
 
         # key(KEY_B) is not executed, the macro stops
@@ -1061,17 +1082,34 @@ class TestIfEq(MacroTestBase):
         self.assertEqual(len(macro.child_macros), 2)
 
     async def test_ifeq_none(self):
-        # first param none
-        macro = parse("set(foo, 2).ifeq(foo, 2, , key(b))", self.context)
+        code_a = system_mapping.get("a")
+
+        # first param None
+        macro = parse("set(foo, 2).ifeq(foo, 2, None, key(b))", self.context)
         self.assertEqual(len(macro.child_macros), 1)
-        code_b = system_mapping.get("b")
         await macro.run(self.handler)
         self.assertListEqual(self.result, [])
 
-        # second param none
-        macro = parse("set(foo, 2).ifeq(foo, 2, key(a),)", self.context)
+        # second param None
+        self.result = []
+        macro = parse("set(foo, 2).ifeq(foo, 2, key(a), None)", self.context)
+        self.assertEqual(len(macro.child_macros), 1)
+        await macro.run(self.handler)
+        self.assertListEqual(self.result, [(EV_KEY, code_a, 1), (EV_KEY, code_a, 0)])
+
+        """Old syntax, use None instead"""
+
+        # first param ""
+        self.result = []
+        macro = parse("set(foo, 2).ifeq(foo, 2, , key(b))", self.context)
+        self.assertEqual(len(macro.child_macros), 1)
+        await macro.run(self.handler)
+        self.assertListEqual(self.result, [])
+
+        # second param ""
+        self.result = []
+        macro = parse("set(foo, 2).ifeq(foo, 2, key(a), )", self.context)
         self.assertEqual(len(macro.child_macros), 1)
-        code_a = system_mapping.get("a")
         await macro.run(self.handler)
         self.assertListEqual(self.result, [(EV_KEY, code_a, 1), (EV_KEY, code_a, 0)])
 
@@ -1092,6 +1130,8 @@ class TestIfEq(MacroTestBase):
         b_press = [(EV_KEY, code_b, 1), (EV_KEY, code_b, 0)]
 
         async def test(macro, expected):
+            """Run the macro and compare the injections with an expectation."""
+            logger.info("Testing %s", macro)
             # cleanup
             macro_variables._clear()
             self.assertIsNone(macro_variables.get("a"))
@@ -1108,11 +1148,14 @@ class TestIfEq(MacroTestBase):
         await test('set(a, "foo").if_eq($a, "foo", key(a), key(b))', a_press)
         await test('set(a, "foo").if_eq("foo", $a, key(a), key(b))', a_press)
         await test('set(a, "foo").if_eq("foo", $a, , key(b))', [])
+        await test('set(a, "foo").if_eq("foo", $a, None, key(b))', [])
         await test('set(a, "qux").if_eq("foo", $a, key(a), key(b))', b_press)
         await test('set(a, "qux").if_eq($a, "foo", key(a), key(b))', b_press)
         await test('set(a, "qux").if_eq($a, "foo", key(a), )', [])
         await test('set(a, "x").set(b, "y").if_eq($b, $a, key(a), key(b))', b_press)
         await test('set(a, "x").set(b, "y").if_eq($b, $a, key(a), )', [])
+        await test('set(a, "x").set(b, "y").if_eq($b, $a, key(a), None)', [])
+        await test('set(a, "x").set(b, "y").if_eq($b, $a, key(a), else=None)', [])
         await test('set(a, "x").set(b, "x").if_eq($b, $a, key(a), key(b))', a_press)
         await test('set(a, "x").set(b, "x").if_eq($b, $a, , key(b))', [])
         await test("if_eq($q, $w, key(a), else=key(b))", a_press)  # both None
